#!/bin/sh
#

#
# starting script for Racer
# - create/update links to all Racer files
#

RACER_DIR="$HOME/.racer";

configured_version=""

test -f $RACER_DIR/racer_version && \
  configured_version=`cat $RACER_DIR/racer_version`

installed_version=`rpm -q racer`

if [ "$configured_version" != "$installed_version" ] ; then
        # create Backup if required
        test -d $RACER_DIR && mv -f $RACER_DIR $RACER_DIR.bak.$configured_version
        echo "Creating Racer directory $RACER_DIR";
        mkdir $RACER_DIR;
        if [ $? != 0 ] ; then
                echo "Failed to create directory $RACER_DIR";
                exit 1;
        fi;
        cd $RACER_DIR;
        rpm -q racer > racer_version
        echo "Creating INI files";
        cp /usr/lib/games/racer/*.ini .
        X=`xdpyinfo -ext XFree86-VidModeExtension|grep -A1 Current|tail -1|awk '{print $2}'`
        Y=`xdpyinfo -ext XFree86-VidModeExtension|grep -A1 Current|tail -1|awk '{print $6}'`
        test -d /proc/asound
        if [ $? -eq 0 ]; then
          sound=1
          # FMOD does not work with ALSA 0.9 at the moment
          #sound_drv=alsa
          sound_drv=oss
        else
          (echo > /dev/dsp) >/dev/null 2>&1
          if [ $? -eq 0 ]; then
            sound=1
            sound_drv=oss
          else
            sound=0
            sound_drv=
          fi
        fi
        sed -e s/width=800/width=$X/ \
            -e s/height=600/height=$Y/ \
            -e s/manage=1/manage=0/ \
            -e 's/ \+enable=1/enable=0/' \
            /usr/lib/games/racer/gfx.ini > gfx.ini
        sed -e s/enable=.*/enable=$sound/ \
            -e s/type=.*/type=$sound_drv/ \
            /usr/lib/games/racer/audio.ini > audio.ini
        sed -e s/default_info=.*/default_info=0/ \
            /usr/lib/games/racer/racer.ini > racer.ini
        #head -c 1 < /dev/js0 &> /dev/null && \
        #  sed -e 's/controls=mouse.ini/;controls=mouse.ini/' \
        #      -e 's/;controls=genjoy.ini/controls=genjoy.ini/' \
        #      racer.ini > /tmp/racer.ini && \
        #    mv /tmp/racer.ini racer.ini
fi;

cd $RACER_DIR;

tracks=`ls -d /usr/lib/games/racer/data/tracks/*|cut -d "/" -f 7,8|grep -v zzz_dummy`
for i in music replays cars $tracks; do 
  mkdir -p data/$i
  ln -snf /usr/lib/games/racer/data/$i/* data/$i
done
for i in ctrlsets drivers fonts images tracks/zzz_dummy; do
  ln -snf /usr/lib/games/racer/data/$i data/$i
done
ln -snf /usr/lib/games/racer/racer .
ln -snf /usr/lib/games/racer/libfmod-3.5.so .

echo "Using Racer directory structure in $RACER_DIR";
xset +fp /usr/X11R6/lib/X11/fonts/misc,/usr/X11R6/lib/X11/fonts/75dpi
xset fp rehash
LD_LIBRARY_PATH=$LD_LIBRARY_PATH:. ./racer $*;
xset -fp /usr/X11R6/lib/X11/fonts/misc,/usr/X11R6/lib/X11/fonts/75dpi
xset fp rehash
mv -f $HOME/QLOG .

exit $!;


